#
# spec file for package python-icalendar
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 7/2011 - now  open-slx GmbH <Sascha.Manns@open-slx.de>
# Copyright (c) 2009 - 7/2011 Sascha Manns <saigkill@opensuse.org> 
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define	modname icalendar
Name:           python-%{modname}
Version:        3.9.1
Release:        3.2
Summary:        Python parser/generator of iCalendar files package
License:        BSD-2-Clause
Group:          Development/Languages/Python
# please see https://github.com/collective/icalendar/issues/2 for re-licensing discussion
Url:            http://icalendar.readthedocs.org
Source0:        https://pypi.python.org/packages/source/i/icalendar/%{modname}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-dateutil
BuildRequires:  python-devel
BuildRequires:  python-pytest
BuildRequires:  python-pytz
BuildRequires:  python-setuptools
Requires:       python-dateutil
Requires:       python-pytz
%{py_requires}
%if 0%{?suse_version} <= 1110
BuildRequires:  python-ordereddict
Requires:       python-ordereddict
BuildRequires:  python-unittest2
Requires:       python-unittest2
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%else
BuildArch:      noarch
%endif
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}

%description
The iCalendar package is a parser/generator of iCalendar files for use
with Python. It follows the RFC 2445 (iCalendar) specification.

%prep
%setup -q -n %{modname}-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes -s %{buildroot}

%check
py.test src

%files
%defattr(-,root,root)
%doc README.rst LICENSE.rst CHANGES.rst
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}-py%{py_ver}.egg-info/

%changelog
* Fri Sep 25 2015 michael@stroeder.com
- Update to 3.9.1:
  - Fix vPeriod.__repr__. [spacekpe]
  - Improve foldline() performance. This improves the foldline
    performance, especially for large strings like base64-encoded
    inline attachements. In some cases (1MB string) from 7 Minutes
    to less than 20ms for ASCII data and 500ms for non-ASCII data.
    Ref: #163. [emfree]
* Mon Jul 13 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Thu Apr 23 2015 mcihar@suse.cz
- Update to 3.9.0:
  - Creating timezone objects from VTIMEZONE components.
  - Make ``python-dateutil`` a dependency.
  - Made RRULE tolerant of trailing semicolons.
  - Documentation fixes.
- Use .tar.gz as Source
- Add missing dependency on pytz, dateutil
- Run testsuite in %%check and adjust build requires
* Wed Nov  5 2014 seiler@b1-systems.de
  update to version 3.8.4 changelog from 3.5
- 3.8.4 (2014-11-01)
  * Add missing BYWEEKNO to recurrence rules. [russkel]
- 3.8.3 (2014-08-26)
  * PERCENT property in VTODO renamed to PERCENT-COMPLETE, according to RFC5545. [thomascube]
- 3.8.2 (2014-07-22)
  * Exclude editor backup files from egg distributions. Fixes #144. [thet]
- 3.8.1 (2014-07-17)
  * The representation of CaselessDicts in 3.8 changed the name attribute of Components and therefore broke the external API. This has been fixed. [untitaker]
- 3.8 (2014-07-17)
  * Allow dots in property names (Needed for vCard compatibility). Refs #143. [untitaker]
  * Change class representation for CaselessDict objects to always include the class name or the class' name attribute, if available. Also show subcomponents for Component objects. [thet]
  * Don't use data_encode for CaselessDict class representation but use dict's __repr__ method. [t-8ch]
  * Handle parameters with multiple values, which is needed for vCard 3.0. Refs #142. [t-8ch]
- 3.7 (2014-06-02)
  * For components with ignore_exceptions set to True, mark unparseable lines as broken instead rising a ValueError. VEVENT components have ignore_exceptions set to True by default. Ref #131. Fixes #104. [jkiang13]
  * Make python-dateutil a soft-dependency. [boltnev]
  * Add optional sorted parameter to Component.to_ical. Setting it to false allows the user to preserve the original property and parameter order. Ref #136. Fixes #133. [untitaker]
  * Fix tests for latest pytz. Don't set tzinfo directly on datetime objects, but use pytz's localize function. Ref #138. [untitaker, thet]
  * Remove incorrect use of __all__. We don't encourage using from package import * imports. Fixes #129. [eric-wieser]
- 3.6.2 (2014-04-05)
  * Pep8 and cleanup. [lasudry]
- 3.6.1 (2014-01-13)
  * Open text files referenced by setup.py as utf-8, no matter what the locale settings are set to. Fixes #122. [sochotnicky]
  * Add tox.ini to source tarball, which simplifies testing for in distributions. [sochotnicky]
- 3.6 (2014-01-06)
  * Python3 (3.3+) + Python 2 (2.6+) support [geier]
  * Made sure to_ical() always returns bytes [geier]
  * Support adding lists to a component property, which value already was a list and remove the Component.set method, which was only used by the add method. [thet]
  * Remove ability to add property parameters via a value's params attribute when adding via cal.add (that was only possible for custom value objects and makes up a strange API), but support a parameter attribute on cal.add's method signature to pass a dictionary with property parameter key/value pairs. Fixes #116. [thet]
  * Backport some of Regebro's changes from his regebro-refactor branch. [thet]
  * Raise explicit error on another malformed content line case. [hajdbo]
  * Correctly parse datetime component property values with timezone information when parsed from ical strings. [untitaker]
* Sat Nov  9 2013 p.drouand@gmail.com
- Use tarball from https://pypi.python.org/
- Fix download link used as source
* Fri Nov  8 2013 aj@ajaissle.de
- New upstream release 3.5
- Changelog for 3.5
  * Let to_unicode be more graceful for non-unicode strings, as like CMFPlone’s safe_unicode does it. [thet]
- Changelog for 3.4
  * Switch to unicode internally. This should fix all en/decoding errors. [thet]
  * Support for non-ascii parameter values. Fixes #88. [warvariuc]
  * Added functions to transform chars in string with ‘\’ + any of r’,;:’ chars into ‘%%{:02X}’ form to avoid splitting on chars escaped with ‘\’. [warvariuc]
  * Allow seconds in vUTCOffset properties. Fixes #55. [thet]
  * Let Component.decode better handle vRecur and vDDDLists properties. Fixes #70. [thet]
  * Don’t let Component.add re-encode already encoded values. This simplifies the API, since there is no need explicitly pass encode=False. Fixes #82. [thet]
  * Rename tzinfo_from_dt to tzid_from_dt, which is what it does. [thet]
  * More support for dateutil parsed tzinfo objects. Fixes #89. [leo-naeka]
  * Remove python-dateutil version fix at all. Current python-dateutil has Py3 and Py2 compatibility. [thet]
  * Declare the required python-dateutil dependency in setup.py. Fixes #90. [kleink]
  * Raise test coverage. [thet]
  * Remove interfaces module, as it is unused. [thet]
  * Remove test_doctests.py, test suite already created properly in test_icalendar.py. [rnix]
  * Transformed doctests into unittests, Test fixes and cleanup. [warvariuc]
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Feb  9 2013 p.drouand@gmail.com
- Update to version 3.3:
  * Drop support for Python < 2.6.
  * Allow vGeo to be instantiated with list and not only tuples of geo
    coordinates. Fixes #83.
  * Don't force to pass a list to vDDDLists and allow setting individual
    RDATE and EXDATE values without having to wrap them in a list.
  * Fix encoding function to allow setting RDATE and EXDATE values and not
    to have bypass encoding with an icalendar property.
  * Allow setting of timezone for vDDDLists and support timezone properties
    for RDATE and EXDATE component properties.
  * Move setting of TZID properties to vDDDTypes, where it belongs to.
  * Use @staticmethod decorator instead of wrapper function.
  * Extend quoting of parameter values to all of those characters: ",;: ’'".
    This fixes an outlook incompatibility with some characters. Fixes: #79, Fixes: #81.
  * Define VTIMETZONE subcomponents STANDARD and DAYLIGHT for RFC5545 compliance.
- Remove the "Clean" section, useless.
* Wed Jan  2 2013 toddrme2178@gmail.com
- Fix building on SLES
* Sat Sep  8 2012 os-dev@jacraig.com
- Update to 3.1:
  * Make sure parameters to certain properties propagate to the ical output.
  * Re-include doctests.
  * endure correct datatype at instance creation time in ``prop.vCalAddress``
    and ``prop.vText``.
  * Apply TZID parameter to datetimes parsed from RECURRENCE-ID
  * Localize datetimes for timezones to avoid DST transition errors.
  * Allow UTC-OFFSET property value data types in seconds, which follows
    RFC5545 specification.
  * Remove utctz and normalized_timezone methods to simplify the codebase. The
    methods were too tiny to be useful and just used at one place.
  * When using Component.add() to add icalendar properties, force a value
    conversion to UTC for CREATED, DTSTART and LAST-MODIFIED. The RFC expects
    UTC for those properties.
  * Removed last occurrences of old API (from_string).
  * Add 'recursive' argument to property_items() to switch recursive listing.
    For example when parsing a text/calendar text including multiple
    components (e.g. a VCALENDAR with 5 VEVENTs), the previous situation
    required us to look over all properties in VEVENTs even if we just want
    the properties under the VCALENDAR component (VERSION, PRODID, CALSCALE,
    METHOD).
  * All unit tests fixed.
- Remove Sphinx dependency since HTML docs aren't generated anymore.
- Don't rm .swp files anymore, they were removed upstream.
* Tue Jun 26 2012 toddrme2178@gmail.com
- Fix building on SLE 11
- updated license to BSD-2-Clause
- Note 1: The fork has taken over maintainership and is now the
  official version
- Note 2: The previous package was a git version from what was the
  fork.  The git tarball had version number 3.0, but for
  completeness this changes entry includes changes since the last
  official release, 2.2
- Update to 3.0.1b2
  * For all TZID parameters in DATE-TIME properties, use timezone
    identifiers (e.g. Europe/Vienna) instead of timezone names
    (e.g. CET), as required by RFC5545. Timezone names are used
    together with timezone identifiers in the Timezone components
  * Timezone parsing, issues and test fixes.
  * Since we use pytz for timezones, also use UTC tzinfo object
    from the pytz  library instead of own implementation.
- Update to 3.0.1b1
  * Update Release information.
- Update to 3.0
  * Add API for proper Timezone support. Allow creating ical
    DATE-TIME strings with timezone information from Python
    datetimes with pytz based timezone information and vice versa
  * Unify API to only use to_ical and from_ical and remove string
    casting as a requirement for Python 3 compatibility:
  * New: to_ical.
  * Old: ical, string, as_string and string casting via __str__
    and str.
  * New: from_ical.
  * Old: from_string.
* Thu Dec 15 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Sep 22 2011 Sascha.Manns@open-slx.de
- fixed license issue
- closed bug bnx#714664
* Sun Aug 28 2011 Sascha.Manns@open-slx.de
- fixed fdupes issue
* Sun Aug 28 2011 Sascha.Manns@open-slx.de
- updated Ownership
- removed rpmlintrc
* Sun Aug 28 2011 hpj@urpla.net
- updated to forked version 2.2
* Fri Dec 24 2010 saigkill@opensuse.org
- removed BuildArch: noarch
* Mon Dec 14 2009 saigkill@opensuse.org
- updated to Version 2.1
* Sun Aug  9 2009 saigkill@opensuse.org
- fixed some little Errors with the lib path
* Sat Apr 18 2009 saigkill@opensuse.org
- removed %%%%buildroot duplicate
* Sat Apr 18 2009 saigkill@opensuse.org
- uses %%%%optflags, %%%%py_requires and
  Sourcepackage (from remote to local)
* Sat Mar 14 2009 saigkill@opensuse.org
- added rpmlintrc
* Thu Jan  8 2009 saigkill@opensuse.org -
- updated Specfile & Makros
* Fri Jan  2 2009 saigkill@opensuse.org 
- python Version 1.2 for openSUSE_11.0
* Thu Jan  1 2009 saigkill@opensuse.org 
- builded initial version iCalendar from SVN Version
